@@ -11,6 +11,7 @@ from peewee import NodeList
 from peewee import Psycopg2Adapter
 from peewee import Psycopg3Adapter
 from peewee import __exception_wrapper__
+from playhouse.pool import _PooledPostgresqlDatabase
 
 try:
     from psycopg2cffi import compat
@@ -57,11 +58,12 @@ class Json(Node):
     # Fallback JSON handler.
     __slots__ = ('value',)
 
-    def __init__(self, value):
+    def __init__(self, value, dumps=None):
         self.value = value
+        self.dumps = dumps or json.dumps
 
     def __sql__(self, ctx):
-        return ctx.value(self.value, json.dumps)
+        return ctx.value(self.value, self.dumps)
 
 
 class _LookupNode(ColumnBase):
@@ -81,7 +83,8 @@ class ObjectSlice(_LookupNode):
     @classmethod
     def create(cls, node, value):
         if isinstance(value, slice):
-            parts = [value.start or 0, value.stop or 0]
+            stop = value.stop - 1 if value.stop is not None else None
+            parts = [value.start or 0, stop]
         elif isinstance(value, int):
             parts = [value]
         elif isinstance(value, Node):
@@ -96,7 +99,8 @@ class ObjectSlice(_LookupNode):
         if isinstance(self.parts, Node):
             ctx.literal('[').sql(self.parts).literal(']')
         else:
-            ctx.literal('[%s]' % ':'.join(str(p + 1) for p in self.parts))
+            ctx.literal('[%s]' % ':'.join([str(p + 1) if p is not None else ''
+                                           for p in self.parts]))
         return ctx
 
     def __getitem__(self, value):
@@ -222,7 +226,9 @@ class HStoreField(IndexedFieldMixin, Field):
     def defined(self, key):
         return fn.defined(self, key)
 
-    def update(self, **data):
+    def update(self, __data=None, **data):
+        if __data is not None:
+            data.update(__data)
         return Expression(self, HUPDATE, data)
 
     def delete(self, *keys):
@@ -285,7 +291,7 @@ class _JsonLookupBase(_LookupNode):
         return Expression(self.as_json(True), JSONB_CONTAINS_KEY, key)
 
     def path(self, *keys):
-        return JsonPath(self.as_json(True), keys)
+        return JsonPath(self.as_json(True), keys, as_json=True)
 
 
 class JsonLookup(_JsonLookupBase):
@@ -316,6 +322,10 @@ class JSONField(FieldDatabaseHook, Field):
     field_type = 'JSON'
     _json_datatype = 'json'
 
+    def __init__(self, dumps=None, **kwargs):
+        self._dumps = dumps
+        super(JSONField, self).__init__(**kwargs)
+
     def _db_hook(self, database):
         if database is None or not hasattr(database, '_adapter'):
             self.json_type = Json
@@ -324,6 +334,13 @@ class JSONField(FieldDatabaseHook, Field):
             self.json_type = database._adapter.json_type
             self.cast_json_case = database._adapter.cast_json_case
 
+        if self._dumps:
+            dumps = self._dumps
+            class _Json(self.json_type):
+                def __init__(self, value):
+                    super(_Json, self).__init__(value, dumps=dumps)
+            self.json_type = _Json
+
     def db_value(self, value):
         if value is None or isinstance(value, (Node, self.json_type)):
             return value
@@ -340,7 +357,7 @@ class JSONField(FieldDatabaseHook, Field):
         return JsonLookup(self, [value])
 
     def path(self, *keys):
-        return JsonPath(self, keys)
+        return JsonPath(self, keys, as_json=True)
 
     def concat(self, value):
         if not isinstance(value, Node):
@@ -361,6 +378,13 @@ class BinaryJSONField(IndexedFieldMixin, JSONField):
             self.json_type = database._adapter.jsonb_type
             self.cast_json_case = database._adapter.cast_json_case
 
+        if self._dumps:
+            dumps = self._dumps
+            class _Json(self.json_type):
+                def __init__(self, value):
+                    super(_Json, self).__init__(value, dumps=dumps)
+            self.json_type = _Json
+
     def contains(self, other):
         if not isinstance(other, Node):
             other = self.json_type(other)
@@ -567,7 +591,15 @@ class PostgresqlExtDatabase(PostgresqlDatabase):
         return cursor
 
 
+class PooledPostgresqlExtDatabase(_PooledPostgresqlDatabase, PostgresqlExtDatabase):
+    pass
+
+
 class Psycopg3Database(PostgresqlExtDatabase):
     def __init__(self, *args, **kwargs):
         kwargs['prefer_psycopg3'] = True
         super(Psycopg3Database, self).__init__(*args, **kwargs)
+
+
+class PooledPsycopg3Database(_PooledPostgresqlDatabase, Psycopg3Database):
+    pass
