@@ -1,6 +1,7 @@
 #coding:utf-8
 import datetime
 import functools
+import json
 import os
 import uuid
 from decimal import Decimal as Dc
@@ -74,6 +75,21 @@ class JData(TestModel):
     d2 = BinaryJSONField(index=False)
 
 
+class UUIDEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, uuid.UUID):
+            return str(obj)
+        return super(UUIDEncoder, self).default(obj)
+
+def dumps(obj):
+    return json.dumps(obj, cls=UUIDEncoder)
+
+
+class CustomJSONDumps(TestModel):
+    jf = JSONField(dumps=dumps)
+    jbf = BinaryJSONField(dumps=dumps)
+
+
 class Normal(TestModel):
     data = TextField()
 
@@ -390,13 +406,22 @@ class TestArrayField(ModelTestCase):
         row = AM.select(T[1].alias('arrtags')).dicts().get()
         self.assertEqual(row['arrtags'], 'beta')
 
+        row = AM.select(T[2:3].alias('foo')).dicts().get()
+        self.assertEqual(row['foo'], ['gamma'])
+
+        row = AM.select(T[:2].alias('foo')).dicts().get()
+        self.assertEqual(row['foo'], ['alpha', 'beta'])
+
+        row = AM.select(T[2:].alias('foo')).dicts().get()
+        self.assertEqual(row['foo'], ['gamma', 'delta'])
+
         row = AM.select(T[2:4].alias('foo')).dicts().get()
         self.assertEqual(row['foo'], ['gamma', 'delta'])
 
         row = AM.select(I[1][1].alias('ints')).dicts().get()
         self.assertEqual(row['ints'], 4)
 
-        row = AM.select(I[1:2][0].alias('ints')).dicts().get()
+        row = AM.select(I[1:3][0].alias('ints')).dicts().get()
         self.assertEqual(row['ints'], [[3], [5]])
 
     @requires_models(DecimalArray)
@@ -644,6 +669,28 @@ class TestJsonFieldRegressions(ModelTestCase):
         self.assertFalse(JD.d2.index)
 
 
+class TestJSONFieldCustomDumps(ModelTestCase):
+    database = db
+    requires = [CustomJSONDumps]
+
+    def test_custom_dumps(self):
+        u1 = uuid.uuid4()
+        u2 = uuid.uuid4()
+
+        data = {'u1': u1, 'u2': u2, 'u3': [u1, u2]}
+        c = CustomJSONDumps.create(jf=data, jbf=data)
+        c_db = CustomJSONDumps.get_by_id(c.id)
+
+        self.assertEqual(c_db.jf, {
+            'u1': str(u1),
+            'u2': str(u2),
+            'u3': [str(u1), str(u2)]})
+        self.assertEqual(c_db.jbf, {
+            'u1': str(u1),
+            'u2': str(u2),
+            'u3': [str(u1), str(u2)]})
+
+
 class TestIntervalField(ModelTestCase):
     database = db
     requires = [Event]
@@ -872,10 +919,30 @@ class TestPostgresIsolationLevel(DatabaseTestCase):
 
         conn.set_isolation_level(2)
         self.assertEqual(conn.isolation_level, 2)
-
         self.database.close()
+
         conn = self.database.connection()
         self.assertEqual(conn.isolation_level, 3)
+        self.database.close()
+
+        self.database.set_isolation_level(2)
+        for _ in range(2):
+            conn = self.database.connection()
+            self.assertEqual(conn.isolation_level, 2)
+            self.database.close()
+
+    def test_isolation_level_str(self):
+        db = db_loader('postgres', isolation_level='SERIALIZABLE')
+        conn = db.connection()
+        self.assertEqual(conn.isolation_level,
+                         db._adapter.isolation_levels_inv['SERIALIZABLE'])
+        db.close()
+
+        db.set_isolation_level('READ COMMITTED')
+        conn = db.connection()
+        self.assertEqual(conn.isolation_level,
+                         db._adapter.isolation_levels_inv['READ COMMITTED'])
+        db.close()
 
 
 @skip_unless(pg12(), 'cte materialization requires pg >= 12')
