@@ -1,4 +1,5 @@
 import asyncio
+import contextvars
 import tempfile
 import os
 import sys
@@ -82,6 +83,25 @@ class TestGreenletSpawn(unittest.IsolatedAsyncioTestCase):
         with self.assertRaises(MissingGreenletBridge):
             await_(Mock())
 
+    async def test_contextvars_handling(self):
+        state = []
+        var = contextvars.ContextVar('data', default='x')
+
+        def get_var():
+            nonlocal state
+            state.append(var.get())
+
+        async def aget_var():
+            await greenlet_spawn(get_var)
+
+        var.set('y')
+
+        await aget_var()
+        await greenlet_spawn(lambda: await_(aget_var()))
+        await aget_var()
+
+        self.assertEqual(state, ['y', 'y', 'y'])
+
 
 class TestTaskLocal(unittest.IsolatedAsyncioTestCase):
     async def test_task_isolation(self):
@@ -695,6 +715,21 @@ class TestDatabaseHelpers(BaseDatabaseTestCase):
         results = await self.db.run(iterate)
         self.assertEqual(results, [])
 
+    async def test_run_contextvars(self):
+        state = []
+        var = contextvars.ContextVar('data', default='x')
+
+        def do_run():
+            nonlocal state
+            state.append(var.get())
+
+        var.set('y')
+        state.append(var.get())
+        await self.db.run(do_run)
+        state.append(var.get())
+
+        self.assertEqual(state, ['y', 'y', 'y'])
+
 
 class TestModelOperations(BaseDatabaseTestCase):
     async def test_create(self):
