@@ -27,7 +27,7 @@ from .sqlite_helpers import json_text_installed
 from .sqlite_helpers import jsonb_installed
 
 
-database = SqliteExtDatabase(':memory:', timeout=100)
+database = SqliteDatabase(':memory:', rank_functions=True, timeout=100)
 
 
 try:
@@ -279,6 +279,32 @@ class TestJSONField(ModelTestCase):
         self.assertEqual(query.count(), 1)
         self.assertEqual(query.get().key, 'k3')
 
+    def test_select_json_value(self):
+        data = (
+            ('k1', {'a': {'b': 'c', 'd': [2, 1, 0]}}),
+        )
+        KeyData.insert_many(data).execute()
+
+        kd = (KeyData
+              .select(KeyData.data['a'].alias('a'))
+              .get())
+        self.assertEqual(kd.a, {'b': 'c', 'd': [2, 1, 0]})
+
+        kd = (KeyData
+              .select(KeyData.data['a']['b'].alias('b'))
+              .get())
+        self.assertEqual(kd.b, 'c')
+
+        kd = (KeyData
+              .select(KeyData.data['a']['d'].alias('d'))
+              .get())
+        self.assertEqual(kd.d, [2, 1, 0])
+
+        kd = (KeyData
+              .select(KeyData.data['a']['d'][0].alias('d0'))
+              .get())
+        self.assertEqual(kd.d0, 2)
+
 
 @skip_unless(json_installed(), 'requires sqlite json1')
 class TestJSONFieldFunctions(ModelTestCase):
@@ -1513,82 +1539,6 @@ class TestRowIDField(ModelTestCase):
         self.assertEqual(5, RowIDModel.select(RowIDModel.rowid).first().rowid)
 
 
-@skip_unless(json_installed(), 'requires json1 sqlite extension')
-class TestJsonContains(ModelTestCase):
-    database = SqliteExtDatabase(':memory:', json_contains=True)
-    requires = [KeyData]
-    test_data = (
-        ('a', {'k1': 'v1', 'k2': 'v2', 'k3': 'v3'}),
-        ('b', {'k2': 'v2', 'k3': 'v3', 'k4': 'v4'}),
-        ('c', {'k3': 'v3', 'x1': {'y1': 'z1', 'y2': 'z2'}}),
-        ('d', {'k4': 'v4', 'x1': {'y2': 'z2', 'y3': [0, 1, 2]}}),
-        ('e', ['foo', 'bar', [0, 1, 2]]),
-    )
-
-    def setUp(self):
-        super(TestJsonContains, self).setUp()
-        with self.database.atomic():
-            for key, data in self.test_data:
-                KeyData.create(key=key, data=data)
-
-    def assertContains(self, obj, expected):
-        contains = fn.json_contains(KeyData.data, json.dumps(obj))
-        query = (KeyData
-                 .select(KeyData.key)
-                 .where(contains)
-                 .order_by(KeyData.key)
-                 .namedtuples())
-        self.assertEqual([m.key for m in query], expected)
-
-    def test_json_contains(self):
-        # Simple checks for key.
-        self.assertContains('k1', ['a'])
-        self.assertContains('k2', ['a', 'b'])
-        self.assertContains('k3', ['a', 'b', 'c'])
-        self.assertContains('kx', [])
-        self.assertContains('y1', [])
-
-        # Partial dictionary.
-        self.assertContains({'k1': 'v1'}, ['a'])
-        self.assertContains({'k2': 'v2'}, ['a', 'b'])
-        self.assertContains({'k3': 'v3'}, ['a', 'b', 'c'])
-        self.assertContains({'k2': 'v2', 'k3': 'v3'}, ['a', 'b'])
-
-        self.assertContains({'k2': 'vx'}, [])
-        self.assertContains({'k2': 'v2', 'k3': 'vx'}, [])
-        self.assertContains({'y1': 'z1'}, [])
-
-        # List, interpreted as list of keys.
-        self.assertContains(['k1', 'k2'], ['a'])
-        self.assertContains(['k4'], ['b', 'd'])
-        self.assertContains(['kx'], [])
-        self.assertContains(['y1'], [])
-
-        # List, interpreted as ordered list of items.
-        self.assertContains(['foo'], ['e'])
-        self.assertContains(['foo', 'bar'], ['e'])
-        self.assertContains(['bar', 'foo'], [])
-
-        # Nested dictionaries.
-        self.assertContains({'x1': 'y1'}, ['c'])
-        self.assertContains({'x1': ['y1']}, ['c'])
-        self.assertContains({'x1': {'y1': 'z1'}}, ['c'])
-        self.assertContains({'x1': {'y2': 'z2'}}, ['c', 'd'])
-        self.assertContains({'x1': {'y2': 'z2'}, 'k4': 'v4'}, ['d'])
-
-        self.assertContains({'x1': {'yx': 'z1'}}, [])
-        self.assertContains({'x1': {'y1': 'z1', 'y3': 'z3'}}, [])
-        self.assertContains({'x1': {'y2': 'zx'}}, [])
-        self.assertContains({'x1': {'k4': 'v4'}}, [])
-
-        # Mixing dictionaries and lists.
-        self.assertContains({'x1': {'y2': 'z2', 'y3': [0]}}, ['d'])
-        self.assertContains({'x1': {'y2': 'z2', 'y3': [0, 1, 2]}}, ['d'])
-
-        self.assertContains({'x1': {'y2': 'z2', 'y3': [0, 1, 2, 4]}}, [])
-        self.assertContains({'x1': {'y2': 'z2', 'y3': [0, 2]}}, [])
-
-
 class CalendarMonth(TestModel):
     name = TextField()
     value = IntegerField()
@@ -1829,7 +1779,7 @@ class TestSqliteReturning(ModelTestCase):
 
 @skip_unless(database.server_version >= (3, 35, 0), 'sqlite returning clause required')
 class TestSqliteReturningConfig(ModelTestCase):
-    database = SqliteExtDatabase(':memory:', returning_clause=True)
+    database = SqliteDatabase(':memory:', returning_clause=True)
     requires = [KVR, User]
 
     def test_pk_set_properly(self):
